#
# spec file for package gnome-pomodoro
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gnome-pomodoro
Version:        0.12.1
Release:        3.2
Summary:        A time management utility for GNOME
License:        GPL-3.0+
Group:          Productivity/Office/Other
Url:            http://gnomepomodoro.org
Source:         https://github.com/codito/%{name}/archive/%{version}.tar.gz
Source99:       gnome-pomodoro-rpmlintrc
BuildRequires:  desktop-file-utils
BuildRequires:  docbook-utils
BuildRequires:  gettext
BuildRequires:  gnome-common
BuildRequires:  gnome-shell >= 3.16.0
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.28
BuildRequires:  pkgconfig(gio-2.0) >= 2.38.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.36.0
BuildRequires:  pkgconfig(gnome-desktop-3.0) >= 3.16.0
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 0.10.1
BuildRequires:  pkgconfig(gsettings-desktop-schemas) >= 3.16.0
BuildRequires:  pkgconfig(gstreamer-1.0) >= 1.0.10
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.13.0
BuildRequires:  pkgconfig(libcanberra) >= 0.30
BuildRequires:  pkgconfig(libpeas-1.0) >= 1.5.0
Requires:       gnome-shell >= 3.13.0
Requires:       gtk3 >= 3.16.0
Requires:       hicolor-icon-theme
Recommends:     %{name}-lang
%glib2_gsettings_schema_requires
%if %{undefined fedora}
%endif
%if %{defined fedora}
BuildRequires:  vala-tools
%endif
%if %{defined fedora}
Requires:       gstreamer1
%else
Requires:       gstreamer
%endif
%if %{defined fedora}
Recommends:     gstreamer1-plugins-base
%else
Recommends:     gstreamer-plugins-base
%endif
%if %{defined fedora}
Obsoletes:      gnome-shell-extension-pomodoro
%endif

%description
A GNOME utility that helps managing time according to Pomodoro Technique. It
intends to improve productivity and focus by taking short breaks after every
25 minutes of work.

%lang_package

%prep
%setup -q

%build
NOCONFIGURE=1 ./autogen.sh
LDFLAGS="-Wl,--as-needed" %configure --disable-static
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot} INSTALL="install -p"
find %{buildroot} -type f -name "*.la" -delete -print
desktop-file-edit %{buildroot}/%{_datadir}/applications/*.desktop \
    --set-key=X-AppInstall-Package --set-value=%{name}

%find_lang %{name}

%check
desktop-file-validate %{buildroot}/%{_datadir}/applications/org.gnome.Pomodoro.desktop

%post
%icon_theme_cache_post
%glib2_gsettings_schema_post
/sbin/ldconfig

%postun
if [ $1 -eq 0 ]; then
    %icon_theme_cache_postun
    %glib2_gsettings_schema_postun
fi
/sbin/ldconfig

%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &> /dev/null || :
glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :

%files lang -f %{name}.lang
%defattr(-,root,root)

%files
%defattr(-,root,root)
%doc README.md COPYING NEWS
%{_bindir}/gnome-pomodoro
%{_datadir}/appdata/org.gnome.Pomodoro.appdata.xml
%{_datadir}/applications/org.gnome.Pomodoro.desktop
%{_datadir}/dbus-1/services/org.gnome.Pomodoro.service
%{_datadir}/glib-2.0/schemas/org.gnome.pomodoro.gschema.xml
%{_datadir}/gnome-pomodoro/
%{_datadir}/gnome-shell/extensions/pomodoro@arun.codito.in
%{_datadir}/icons/hicolor/*/apps/*
%{_mandir}/man1/gnome-pomodoro.1*
#make it work for :42
%dir %{_datadir}/appdata
%{_libdir}/gnome-pomodoro/
%{_libdir}/libgnome-pomodoro.so*

%changelog
* Mon Jun 20 2016 mvetter@suse.com
- Update to version 0.12.1:
  + Fix for build error.
- Add gnome-pomodoro-rpmlintrc: lib is only used by pomodoro.
- BuildRequire pkgconfig(gio-2.0) instead of
  pkgconfig(dbus-glib-1): Migrated from libdubs-glib to GDBus.
- Drop BuildRequires/Recommends for:
  + telepathy-glib: Drop integration with Telepathy.
  + google-droid-sans-fonts: Don't use Droid Sans for timer digits,
    instead use default system font.
- Added BuildRequires:
  + gsettings-desktop-schemas: to provide fallback for other
    desktops.
  + pkgconfig(libpeas): added a plugin engine based on libpeas.
- Drop passing of prefix to autogen as it gets done in there
  automatically.
- Linker flags changed due to issues:
  gh#codito/gnome-pomodoro#159 and gh#codito/gnome-pomodoro#195.
* Mon Jun 13 2016 mvetter@suse.com
- Update to version 0.12.0:
  + Support for more desktops.
  + Ability to pause the timer.
  + Ability add plugins.
  + Code refactoring.
  + Bug fixes.
  + Dropped Telepathy and Skype integration.
  + Dropped support for GNOME Shell 3.14 and older.
* Wed May 18 2016 mvetter@suse.com
- Update to version 0.11.3:
  + Ignore small mouse movements in screen notification.
  + Fixed indicator not updating.
  + Cleaned up some compilation warnings.
* Mon Apr  4 2016 mvetter@suse.com
- Update to version 0.11.2:
  + Add GNOME 3.20 support.
* Fri Nov 13 2015 mvetter@suse.com
- Update to version 0.11.1:
  + Add GNOME 3.18 support.
  + Updated translations.
* Tue Jul 14 2015 mvetter@suse.com
- Correct glib2 macros
* Mon Jul 13 2015 mvetter@suse.com
- Using macros in post/postun
- Splitting in lang package
- Use proper configure
* Thu Jul  2 2015 mvetter@suse.com
- Remove deb file
- Clean up spec file
- Correct name of spec file and add changes file
- Package got created originally by Kamil Prusko (kamilprusko)
